@@ -2,13 +2,11 @@ use crate::compiler::BinCode;
 use genawaiter::{rc::gen, yield_};
 use serde::Deserialize;
 use std::collections::HashMap;
-use themelio_stf::{
-    melvm::{
-        self,
-        opcode::{DecodeError, OpCode},
-        Covenant, Executor, Value,
-    },
-    CoinDataHeight, CoinID, Header, Transaction,
+use themelio_structs::{CoinDataHeight, CoinID, Header, Transaction};
+use themelio_stf::melvm::{
+    self,
+    opcode::{DecodeError, OpCode},
+    Covenant, Executor, Value,
 };
 
 /// Points to current instruction of a program in an [ExecutionEnv].
@@ -122,8 +120,7 @@ mod tests {
     use crate::parser::parse;
     use crate::types::MelExpr;
     use ethnum::U256;
-    use imbl::vector;
-    use themelio_stf::{melvm::Address, CoinData, TxHash, TxKind};
+    use themelio_structs::{Address, CoinData, TxHash, TxKind, Denom, NetID};
     use tmelcrypt::{ed25519_keygen, Ed25519PK, Ed25519SK, HashVal};
 
     fn empty_test() -> Transaction {
@@ -132,7 +129,7 @@ mod tests {
             inputs: Vec::new(),
             outputs: Vec::new(),
             fee: 0.into(),
-            scripts: Vec::new(),
+            covenants: Vec::new(),
             data: Vec::new(),
             sigs: Vec::new(),
         }
@@ -159,9 +156,9 @@ mod tests {
         };
         let empty_cdh = CoinDataHeight {
             coin_data: CoinData {
-                covhash: Address::coin_destroy(), //tmelcrypt::HashVal::default().to_addr(),
+                covhash: Address::coin_destroy(),
                 value: 0.into(),
-                denom: themelio_stf::Denom::Mel,
+                denom: Denom::Mel,
                 additional_data: input.into(),
             },
             height: 0.into(),
@@ -172,7 +169,7 @@ mod tests {
             parent_cdh: empty_cdh,
             spender_index: 0,
             last_header: Header {
-                network: themelio_stf::NetID::Testnet,
+                network: NetID::Testnet,
                 previous: HashVal::default(),
                 height: 0.into(),
                 history_hash: HashVal::default(),
@@ -199,6 +196,15 @@ mod tests {
         assert_eq!(state.0, vec![Value::Int(U256::new(3))]);
     }
 
+    #[test]
+    fn exp_numbers() {
+        let ops = parse("(** 2 2 4)").unwrap();
+        let (pk, sk, tx) = key_and_empty_tx();
+        let state = exec(&tx, &[], ops);
+
+        assert_eq!(state.0, vec![Value::Int(U256::new(16))]);
+    }
+
     #[test]
     fn test_eql() {
         let ops = parse("(= 1 1)").unwrap();
@@ -243,7 +249,7 @@ mod tests {
 
         assert_eq!(
             state.0,
-            vec![Value::Vector(vector![Value::Int(U256::new(1))])]
+            vec![Value::Vector(vec![Value::Int(U256::new(1))].into())]
         );
     }
 
@@ -255,10 +261,10 @@ mod tests {
 
         assert_eq!(
             state.0,
-            vec![Value::Vector(vector![
+            vec![Value::Vector(vec![
                 Value::Int(U256::new(2)),
                 Value::Int(U256::new(1))
-            ])]
+            ].into())]
         );
     }
 
@@ -349,10 +355,10 @@ mod tests {
 
         assert_eq!(
             state.0,
-            vec![Value::Bytes(vector![
+            vec![Value::Bytes(vec![
                 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                 0, 0, 0, 1
-            ])]
+            ].into())]
         );
     }
 
@@ -407,7 +413,7 @@ mod tests {
         let (_, _, tx) = key_and_empty_tx();
         let state = exec(&tx, &[], ops);
 
-        assert_eq!(state.0, vec![Value::Bytes(vector![2])]);
+        assert_eq!(state.0, vec![Value::Bytes(vec![2].into())]);
     }
 
     #[test]
@@ -418,7 +424,7 @@ mod tests {
 
         assert_eq!(
             state.0,
-            vec![Value::Vector(vector![Value::Int(U256::new(2))])]
+            vec![Value::Vector(vec![Value::Int(U256::new(2))].into())]
         );
     }
 
@@ -428,7 +434,7 @@ mod tests {
         let (_, _, tx) = key_and_empty_tx();
         let state = exec(&tx, &[], ops);
 
-        assert_eq!(state.0, vec![Value::Bytes(vector![2])]);
+        assert_eq!(state.0, vec![Value::Bytes(vec![2].into())]);
     }
 
     #[test]
@@ -458,7 +464,7 @@ mod tests {
         let (_, _, tx) = key_and_empty_tx();
         let state = exec(&tx, &[], ops);
 
-        assert_eq!(state.0, vec![Value::Bytes(vector![])]);
+        assert_eq!(state.0, vec![Value::Bytes(vec![].into())]);
     }
 
     #[test]
@@ -482,11 +488,11 @@ mod tests {
 
         assert_eq!(
             state.0,
-            vec![Value::Vector(vector![
+            vec![Value::Vector(vec![
                 Value::Int(U256::new(1)),
                 Value::Int(U256::new(2)),
                 Value::Int(U256::new(3))
-            ])]
+            ].into())]
         );
     }
 
@@ -589,11 +595,11 @@ mod tests {
 
         if let themelio_stf::melvm::Value::Bytes(im_bytes) = state.0.pop().unwrap() {
             assert_eq!(
-                im_bytes.into_iter().collect::<Vec<u8>>(),
+                im_bytes,
                 vec![
                     233, 131, 224, 169, 229, 83, 12, 43, 119, 20, 230, 120, 233, 61, 188, 129, 150,
                     148, 124, 190, 111, 195, 63, 163, 212, 106, 36, 240, 111, 251, 98, 193
-                ]
+                ].into()
             );
         } else {
             panic!();
@@ -618,6 +624,18 @@ mod tests {
         assert_eq!(state.0, vec![Value::Int(U256::new(1))]);
     }
 
+    /*
+    #[test]
+    fn overflow() {
+        let max = U256::MAX;
+        let ops = crate::parser::parse_no_optimize(&format!("(let (x (+ {max} 10)) oflo)")).unwrap();
+        let (_, _, tx) = key_and_empty_tx();
+        let state = exec(&tx, &[], ops);
+
+        assert_eq!(state.0, vec![Value::Int(U256::new(1))]);
+    }
+    */
+
     /*
     #[test]
     fn fn_no_capture() {
